powered by
returns the day of the year from a 'timeDate' object.
dayOfWeek(x)
returns a three letter character string with the names in English of the day of the week,
an object of class timeDate.
timeDate
dayOfYear
## timeCalendar - tC = timeCalendar() ## The days of the Year: dayOfWeek(tC)
Run the code above in your browser using DataLab