Learn R Programming

timeDate (version 4021.106)

dayOfYear: Day of the Year

Description

returns the day of the year from a 'timeDate' object.

Usage

dayOfYear(x)

Value

returns the day count as integer value starting January, 1st.

Arguments

x

an object of class timeDate.

See Also

dayOfWeek

Examples

Run this code
## timeCalendar -  
   tC = timeCalendar()
       
## The days of the Year:
   dayOfYear(tC)

Run the code above in your browser using DataLab