Learn R Programming

timeDate (version 4021.106)

holidayTSX: TSX Holiday Calendar

Description

Returns a holiday calendar for the Toronto Stock Exchange.

Usage

holidayTSX(year = getRmetricsOptions("currentYear"))

Value

returns an object of class timeDate.

Arguments

year

an integer value or vector of years, formatted as YYYY.

Examples

Run this code
## holidayTSX -
   holidayTSX()
   holidayTSX(2008:2010)

Run the code above in your browser using DataLab