Generic function for computation of kurtosis. The methods defined in package timeDate are described here.
kurtosis(x, ...)# S3 method for default
kurtosis(x, na.rm = FALSE,
method = c("excess", "moment", "fisher"), ...)
# S3 method for data.frame
kurtosis(x, na.rm = FALSE,
method = c("excess", "moment", "fisher"), ...)
# S3 method for POSIXct
kurtosis(x, ...)
# S3 method for POSIXlt
kurtosis(x, ...)
a numeric value or vector with attribute "method" indicating
the method.
a logical. Should missing values be removed?
a character string which specifies the method of computation.
These are either "moment", "fisher", or "excess".
If "excess" is
selected, then the value of the kurtosis is computed by the
"moment" method and a value of 3 will be subtracted.
The "moment" method is based on the definitions of
kurtosis for distributions; these forms should
be used when resampling (bootstrap or jackknife). The
"fisher" method correspond to the usual "unbiased"
definition of sample variance, although in the case of
kurtosis exact unbiasedness is not possible.
a numeric vector or object.
arguments to be passed.
kurtosis is an S3 generic function. This page describes the
methods defined in package dateTime.
If x is numeric the kurtosis is computed according to the
description given for argument method. A logical vector is
treated as a vector of 1's and 0's.
The data.frame method applies kurtosis recursively to
each column. The POSIXlt method computes the kurtosis of the
underlying numerical representation of the date/times. The method for
POSIXct does the same after converting the argument to
POSIXlt.
The default method returns NA, with a warning, if it can't
handle argument x.
skewness.
## mean -
## var -
# Mean, Variance:
r = rnorm(100)
mean(r)
var(r)
## kurtosis -
kurtosis(r)
kurtosis(data.frame(r = r, r2 = r^2))
Run the code above in your browser using DataLab