Learn R Programming

timeDate (version 4021.106)

listFinCenter: List of Financial Centers

Description

Lists supported financial centers.

Usage

listFinCenter(pattern = ".*")

Value

a character vector listing the financial centers whose names match

pattern.

Arguments

pattern

a pattern character string as required by the grep function. The default, ".*", gives all supported financial centers

See Also

rulesFinCenter for the daylight saving rules

Examples

Run this code
## myFinCenter - the global setting currently used:
   getRmetricsOptions("myFinCenter")

## Other Financial Centers:
   listFinCenter("Asia/")
   listFinCenter("^A")    # all beginning with "A"
   listFinCenter("^[^A]") # all *not* beginning with "A"
   listFinCenter(".*/L")  # cities with L*

   stopifnot(identical(sort(listFinCenter()), ## 'A' and 'not A' == everything:
        sort(union(listFinCenter("^A"),
            listFinCenter("^[^A]")))))

Run the code above in your browser using DataLab