Learn R Programming

timeDate (version 4021.106)

rulesFinCenter: Financial Centers DST Rules

Description

Returns DST rules for a financial center.

Usage

rulesFinCenter(FinCenter = "")

Value

a list of time zones and DST rules available in the database.

Arguments

FinCenter

a character string with the location of the financial center named as "continent/city".

Details

The function rulesFinCenter lists the daylight saving rules for a selected financial center.

There is no dependency on the POSIX implementation of your operating system because all time zone and day light saving time information is stored locally in ASCII files.

See Also

listFinCenter for a list of the available financial centers

Examples

Run this code
## rulesFinCenter - 
   rulesFinCenter("Zurich")

Run the code above in your browser using DataLab