Learn R Programming

timeDate (version 4021.106)

skewness: Skewness

Description

Functions to compute skewness.

Usage

skewness(x, ...)

# S3 method for default skewness(x, na.rm = FALSE, method = c("moment", "fisher"), ...)

# S3 method for data.frame skewness(x, na.rm = FALSE, method = c("moment", "fisher"), ...)

# S3 method for POSIXct skewness(x, ...)

# S3 method for POSIXlt skewness(x, ...)

Value

a numeric value or vector with attribute "method" indicating the method.

Arguments

na.rm

a logical. Should missing values be removed?

method

a character string which specifies the method of computation. These are either "moment" or "fisher" The "moment" method is based on the definitions of skewnessfor distributions; these forms should be used when resampling (bootstrap or jackknife). The "fisher" method correspond to the usual "unbiased" definition of sample variance, although in the case of skewness exact unbiasedness is not possible.

x

a numeric vector or object.

...

arguments to be passed.

See Also

kurtosis.

Examples

Run this code
## mean -
## var -
   # Mean, Variance:
   r = rnorm(100)
   mean(r)
   var(r)
   
## skewness -
   skewness(r)  

Run the code above in your browser using DataLab