a numeric value or vector with attribute "method" indicating
the method.
Arguments
na.rm
a logical. Should missing values be removed?
method
a character string which specifies the method of computation.
These are either "moment" or "fisher"
The "moment" method is based on the definitions of
skewnessfor distributions; these forms should
be used when resampling (bootstrap or jackknife). The
"fisher" method correspond to the usual "unbiased"
definition of sample variance, although in the case of skewness
exact unbiasedness is not possible.